==> ecp_sync_plugin-6.8.6.tar.gz: android/src/main/java/ecp/vcs/com/ecpsyncplugin/re_sync/authorization/Authentication.java <==
package ecp.vcs.com.ecpsyncplugin.re_sync.authorization;

import android.content.Context;
import org.json.JSONException;
import org.json.JSONObject;

import ecp.vcs.com.ecpsyncplugin.re_sync.SynchronizationService;
import ecp.vcs.com.ecpsyncplugin.re_sync.database.DatabaseHelperExtended;
import ecp.vcs.com.ecpsyncplugin.re_sync.database.DataBaseHelper;
import ecp.vcs.com.ecpsyncplugin.re_sync.networking.AppUtil;
import ecp.vcs.com.ecpsyncplugin.re_sync.utils.Const;
import ecp.vcs.com.ecpsyncplugin.re_sync.utils.Content;


public class Authentication {

    private static Authentication instance; // automatically initialized to null

    private static DataBaseHelper databaseHelper;
    private static DatabaseHelperExtended databaseHelperExtended;
    private static final String KEY_USER_ID = "user_id";
    private static final String KEY_PASSWORD = "password";
    private static final String KEY_VERSION = "version";
    private static final String KEY_VERSION_CODE = "version_code";
    private static final String KEY_IMEI = "imei";
    private static final String KEY_COUNTRY_ID = "country_id";

    public static final String KEY_AUTH = "auth";
    public static final String KEY_DATA = "data";
    public static String KEY_REQUEST_PARAM = "request_param";
    private static Context context;


    public static Authentication getInstance(Context context) {
        if (instance == null) {
            Authentication.context = context;
            instance = new Authentication();
            databaseHelper = new DataBaseHelper(Authentication.context);
            databaseHelperExtended = new DatabaseHelperExtended(Authentication.context);
        }

        return instance;
    }


    public JSONObject getRequestParam(JSONObject authentication, JSONObject objData) {
        try {
//            JSONObject requestParam=new JSONObject();
            JSONObject objAuth = new JSONObject();
            objAuth.put(Authentication.KEY_AUTH, authentication);
            objAuth.put(Authentication.KEY_DATA, objData);
//            requestParam.put(Authentication.KEY_REQUEST_PARAM,objAuth);
            return objAuth;
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return null;
    }

    public JSONObject getAuth(String countryID) {
        try {
            JSONObject objBody = new JSONObject();

            objBody.put(KEY_USER_ID, databaseHelper.getLoginUserId());
            objBody.put(KEY_PASSWORD, databaseHelperExtended.getLoginPassword());
            objBody.put(KEY_VERSION, AppUtil.getAppVersion(context));
            objBody.put(KEY_VERSION_CODE, AppUtil.getAppVersionCode(context));
            objBody.put(KEY_IMEI, AppUtil.getIMEINo(context));
            objBody.put(KEY_COUNTRY_ID, countryID);

            return objBody;
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * Get Sync Data
     *
     * @param fileName
     * @param syncLogId
     * @return
     */
    public JSONObject getSyncDataNew(String fileName, String syncLogId,Context context,String syncType) {
        try {
            JSONObject objBody = new JSONObject();
            objBody.put(Const.WEB_SERVICES_PARAM.KEY_FILE_NAME, fileName);
            objBody.put(Const.WEB_SERVICES_PARAM.KEY_SYNC_LOG_ID, syncLogId);
            objBody.put(Const.WEB_SERVICES_PARAM.KEY_sync_date, databaseHelper.getSyncDateAndTime());
//            objBody.put(Const.WEB_SERVICES_PARAM.date_folder, Content.getPreferenceValue(context, Const.dateUpload));
            objBody.put(Const.WEB_SERVICES_PARAM.date_folder, SynchronizationService.dateFolder);
            objBody.put(Const.WEB_SERVICES_PARAM.KEY_SYNC_TYPE, syncType);

//            if (!Content.getPreferenceValue(context,Content.SYNC_TYPE).isEmpty()){
//                objBody.put(Const.WEB_SERVICES_PARAM.KEY_FLAG, Content.getPreferenceValue(context,Content.SYNC_TYPE));
//            }else {
//                objBody.put(Const.WEB_SERVICES_PARAM.KEY_FLAG, "H");
//            }

            if (!syncType.isEmpty()){
                objBody.put(Const.WEB_SERVICES_PARAM.KEY_FLAG, syncType);
            }else {
                objBody.put(Const.WEB_SERVICES_PARAM.KEY_FLAG, "H");
            }

            return objBody;
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return null;
    }

    public JSONObject getUserPoints(String user_id, String country_id,String date_folder) {
        try {
            JSONObject objBody = new JSONObject();
            objBody.put("country_id", country_id);
            objBody.put("user_id", user_id);
            objBody.put("date_folder", date_folder);
            return objBody;
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return null;
    }

}

==> ecp_sync_plugin-6.8.7.tar.gz: android/src/main/java/ecp/vcs/com/ecpsyncplugin/re_sync/authorization/Authentication.java <==
package ecp.vcs.com.ecpsyncplugin.re_sync.authorization;

import android.content.Context;
import org.json.JSONException;
import org.json.JSONObject;

import ecp.vcs.com.ecpsyncplugin.re_sync.SynchronizationService;
import ecp.vcs.com.ecpsyncplugin.re_sync.database.DatabaseHelperExtended;
import ecp.vcs.com.ecpsyncplugin.re_sync.database.DataBaseHelper;
import ecp.vcs.com.ecpsyncplugin.re_sync.networking.AppUtil;
import ecp.vcs.com.ecpsyncplugin.re_sync.utils.Const;
import ecp.vcs.com.ecpsyncplugin.re_sync.utils.Content;


public class Authentication {

    private static Authentication instance; // automatically initialized to null

    private static DataBaseHelper databaseHelper;
    private static DatabaseHelperExtended databaseHelperExtended;
    private static final String KEY_USER_ID = "user_id";
    private static final String KEY_PASSWORD = "password";
    private static final String KEY_VERSION = "version";
    private static final String KEY_VERSION_CODE = "version_code";
    private static final String KEY_IMEI = "imei";
    private static final String KEY_COUNTRY_ID = "country_id";

    public static final String KEY_AUTH = "auth";
    public static final String KEY_DATA = "data";
    public static String KEY_REQUEST_PARAM = "request_param";
    private static Context context;


    public static Authentication getInstance(Context context) {
        if (instance == null) {
            Authentication.context = context;
            instance = new Authentication();
            databaseHelper = new DataBaseHelper(Authentication.context);
            databaseHelperExtended = new DatabaseHelperExtended(Authentication.context);
        }

        return instance;
    }


    public JSONObject getRequestParam(JSONObject authentication, JSONObject objData) {
        try {
//            JSONObject requestParam=new JSONObject();
            JSONObject objAuth = new JSONObject();
            objAuth.put(Authentication.KEY_AUTH, authentication);
            objAuth.put(Authentication.KEY_DATA, objData);
//            requestParam.put(Authentication.KEY_REQUEST_PARAM,objAuth);
            return objAuth;
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return null;
    }

    public JSONObject getAuth(String countryID,String userID,String password) {
        try {
            JSONObject objBody = new JSONObject();

            objBody.put(KEY_USER_ID, userID);
            objBody.put(KEY_PASSWORD, password);
            objBody.put(KEY_VERSION, AppUtil.getAppVersion(context));
            objBody.put(KEY_VERSION_CODE, AppUtil.getAppVersionCode(context));
            objBody.put(KEY_IMEI, AppUtil.getIMEINo(context));
            objBody.put(KEY_COUNTRY_ID, countryID);

            return objBody;
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * Get Sync Data
     *
     * @param fileName
     * @param syncLogId
     * @return
     */
    public JSONObject getSyncDataNew(String fileName, String syncLogId,Context context,String syncType) {
        try {
            JSONObject objBody = new JSONObject();
            objBody.put(Const.WEB_SERVICES_PARAM.KEY_FILE_NAME, fileName);
            objBody.put(Const.WEB_SERVICES_PARAM.KEY_SYNC_LOG_ID, syncLogId);
            objBody.put(Const.WEB_SERVICES_PARAM.KEY_sync_date, databaseHelper.getSyncDateAndTime());
//            objBody.put(Const.WEB_SERVICES_PARAM.date_folder, Content.getPreferenceValue(context, Const.dateUpload));
            objBody.put(Const.WEB_SERVICES_PARAM.date_folder, SynchronizationService.dateFolder);
            objBody.put(Const.WEB_SERVICES_PARAM.KEY_SYNC_TYPE, syncType);

//            if (!Content.getPreferenceValue(context,Content.SYNC_TYPE).isEmpty()){
//                objBody.put(Const.WEB_SERVICES_PARAM.KEY_FLAG, Content.getPreferenceValue(context,Content.SYNC_TYPE));
//            }else {
//                objBody.put(Const.WEB_SERVICES_PARAM.KEY_FLAG, "H");
//            }

            if (!syncType.isEmpty()){
                objBody.put(Const.WEB_SERVICES_PARAM.KEY_FLAG, syncType);
            }else {
                objBody.put(Const.WEB_SERVICES_PARAM.KEY_FLAG, "H");
            }

            return objBody;
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return null;
    }

    public JSONObject getUserPoints(String user_id, String country_id,String date_folder) {
        try {
            JSONObject objBody = new JSONObject();
            objBody.put("country_id", country_id);
            objBody.put("user_id", user_id);
            objBody.put("date_folder", date_folder);
            return objBody;
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return null;
    }

}
